summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStefan Sauer <ensonic@users.sf.net>2017-10-23 11:52:38 +0200
committerTim-Philipp Müller <tim@centricular.com>2017-12-02 15:10:27 +0000
commit917214ed91325b30c34c6ed5d56b31fff53acb0f (patch)
tree8264293675fd0b77cabe367f815eddce2a7767d9
parent063787d7705629bc269388b65a9e7cc4b328e02f (diff)
tests: comment and logging cleanups for audiomixer and aggregator
Remove some references to 'collectpads'. Logs pads through the object variants. Add some more comments. Remove a left over comment.
-rw-r--r--tests/check/libs/aggregator.c13
1 files changed, 8 insertions, 5 deletions
diff --git a/tests/check/libs/aggregator.c b/tests/check/libs/aggregator.c
index 28a0c46fe..06ef40311 100644
--- a/tests/check/libs/aggregator.c
+++ b/tests/check/libs/aggregator.c
@@ -593,8 +593,6 @@ GST_START_TEST (test_aggregate_handle_queries)
g_thread_join (thread1);
g_thread_join (thread2);
- // FIXME: need to make sure all data was aggregated
-
_chain_data_clear (&data1);
_chain_data_clear (&data2);
_test_data_clear (&test);
@@ -819,20 +817,24 @@ GST_START_TEST (test_flushing_seek)
fail_unless_equals_int (test.flush_start_events, 0);
fail_unless_equals_int (test.flush_stop_events, 0);
- /* flush ogg:sink_0. This flushs collectpads, calls ::flush() and sends
- * FLUSH_START downstream */
- GST_DEBUG ("Flushing: %s:%s", GST_DEBUG_PAD_NAME (data2.sinkpad));
+ /* send a first FLUSH_START on agg:sink_0, will be sent downstream */
+ GST_DEBUG_OBJECT (data2.sinkpad, "send flush_start");
fail_unless (gst_pad_push_event (data2.srcpad, gst_event_new_flush_start ()));
+ fail_unless_equals_int (test.flush_start_events, 1);
+ fail_unless_equals_int (test.flush_stop_events, 0);
/* expect this buffer to be flushed */
data2.expected_result = GST_FLOW_FLUSHING;
thread2 = g_thread_try_new ("gst-check", push_data, &data2, NULL);
+ /* this should send not additional flush_start */
+ GST_DEBUG_OBJECT (data1.sinkpad, "send flush_start");
fail_unless (gst_pad_push_event (data1.srcpad, gst_event_new_flush_start ()));
fail_unless_equals_int (test.flush_start_events, 1);
fail_unless_equals_int (test.flush_stop_events, 0);
/* the first FLUSH_STOP is not forwarded downstream */
+ GST_DEBUG_OBJECT (data1.srcpad, "send flush_stop");
fail_unless (gst_pad_push_event (data1.srcpad,
gst_event_new_flush_stop (TRUE)));
fail_unless_equals_int (test.flush_start_events, 1);
@@ -848,6 +850,7 @@ GST_START_TEST (test_flushing_seek)
/* flush agg:sink_1 as well. This completes the flushing seek so a FLUSH_STOP is
* sent downstream */
+ GST_DEBUG_OBJECT (data2.srcpad, "send flush_stop");
gst_pad_push_event (data2.srcpad, gst_event_new_flush_stop (TRUE));
/* and the last FLUSH_STOP is forwarded downstream */